CommandToRun class

Constructors

CommandToRun({required String command, required String workingDirectory, List<String>? keys, bool runConcurrently = false, List<String> envFile = const [], String? label})
const

Properties

command → String
final
envFile → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
keys → List<String>?
final
label → String
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runConcurrently → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
workingDirectory → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited