OptionalFlags class

A class to parse optional flags from a list of strings.

e.g. ['-f', 'file.txt', '--verbose', 'true'] would be parsed to {'-f': '-f file.txt', '--verbose': '--verbose true'}

Constructors

OptionalFlags(List<String> _flags)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
isNotEmpty → bool
no setter
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String key) → String?