Script class

Parses an entry from the scripts.yaml file

Annotations
  • @JsonSerializable.new(constructor: 'defaults')

Constructors

Script({required String name, required List<String> commands, required Set<String> aliases, required String? description, required ScriptsConfig? scripts, required bool bail, required List<String>? parents, required ScriptEnv? env})
const
Script.defaults({required String name, List<String> commands = const [], Set<String> aliases = const {}, ScriptsConfig? scripts, String? description, bool bail = false, List<String>? parents, ScriptEnv? env})
const
Script.fromJson(String name, dynamic json, {List<String>? parents})
factory

Properties

aliases → Set<String>
final
bail → bool
final
commands → List<String>
final
description → String?
final
env → ScriptEnv?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
parents → List<String>?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scripts → ScriptsConfig?
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

listOut({StringBuffer? buffer, String? prefix, String wrapCallableKey(String)?, String wrapNonCallableKey(String)?, String wrapMeta(String)?}) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited