ScriptsYaml class abstract interface

This is the interface for the scripts.yaml file.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

nearest() → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse() → Map<String, dynamic>?
retrieveContent() → String?
scripts() → Map<String, dynamic>?
toString() → String
A string representation of this object.
inherited
variables() → Map<String, dynamic>?

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fileName → const String