Logger class

Constructors

Logger()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

detail → Log
no setter
err → Log
no setter
warn → Log
no setter
write → Log
no setter

Static Methods

setup({required Log detail, required Log err, required Log warn, required Log write}) → void